function Julija(c,rez,iter,X,Y)
% c - fiksirano c
% iter - broj iteracija u Mandelbrotovom skupu
% rez  - "rezolucija", tj. broj tacaka unutar slike
% X -  vektor duzine 2, x koordinate, grafik se crta od X(1) do X(2)
% Y -  vektor duzine 2, y koordinate, grafik se crta od Y(1) do Y(2)

% test:
% Julija(i,400,100,[-1.5,1.5],[-1.5,1.5])
% Julija(0.5i,400,100,[-1.5,1.5],[-1.5,1.5])
% Julija(0.8i,400,100,[-1.5,1.5],[-1.5,1.5])

% z(n+1) = z(n)^2 + c
% za fiksirano c, menjamo z(0)

[zRe,zIm]=meshgrid(linspace(X(1),X(2),rez),linspace(Y(1),Y(2),rez));
z=zRe+1i*zIm;
for i = 1:rez
    for j=1:rez
        M(i,j)=Julija_pom(z(i,j),c,iter);
    end
end

imagesc(M); % crta sliku

function  iz=Julija_pom(z0,c,iter)

R=2;
iz=iter;
z=z0;
for i=1:iter
    if abs(z) > R
        iz = i;
        return;
    end   
    z=z^2+c;
end
